@@ -8,7 +8,10 @@ from .vegalite import VegaLite
 
 __all__ = ['Vega', 'VegaLite']
 
-__version__ = '0.11.0'
+__version__ = '0.13.0'
+
+import warnings
+warnings.warn("The vega3 module is deprecated. Use vega instead.", DeprecationWarning, stacklevel=2)
 
 
 def _jupyter_nbextension_paths():
